@@ -201,7 +201,24 @@ TekHVC_ParseString(
 	    &pColor->spec.TekHVC.H,
 	    &pColor->spec.TekHVC.V,
 	    &pColor->spec.TekHVC.C) != 3) {
-	return(XcmsFailure);
+        char *s; /* Maybe failed due to locale */
+        int f;
+        if ((s = strdup(spec))) {
+            for (f = 0; s[f]; ++f)
+                if (s[f] == '.')
+                    s[f] = ',';
+                else if (s[f] == ',')
+                    s[f] = '.';
+	    if (sscanf(s + n + 1, "%lf/%lf/%lf",
+		       &pColor->spec.TekHVC.H,
+		       &pColor->spec.TekHVC.V,
+		       &pColor->spec.TekHVC.C) != 3) {
+                free(s);
+                return(XcmsFailure);
+            }
+            free(s);
+        } else
+	    return(XcmsFailure);
     }
     pColor->format = XcmsTekHVCFormat;
     pColor->pixel = 0;
@@ -313,11 +330,11 @@ XcmsTekHVC_ValidSpec(
  *	SYNOPSIS
  */
 Status
-XcmsTekHVCToCIEuvY(ccc, pHVC_WhitePt, pColors_in_out, nColors)
-    XcmsCCC ccc;
-    XcmsColor *pHVC_WhitePt;
-    XcmsColor *pColors_in_out;
-    unsigned int nColors;
+XcmsTekHVCToCIEuvY(
+    XcmsCCC ccc,
+    XcmsColor *pHVC_WhitePt,
+    XcmsColor *pColors_in_out,
+    unsigned int nColors)
 /*
  *	DESCRIPTION
  *		Transforms an array of TekHVC color specifications, given
@@ -434,11 +451,11 @@ XcmsTekHVCToCIEuvY(ccc, pHVC_WhitePt, pColors_in_out, nColors)
  *	SYNOPSIS
  */
 Status
-XcmsCIEuvYToTekHVC(ccc, pHVC_WhitePt, pColors_in_out, nColors)
-    XcmsCCC ccc;
-    XcmsColor *pHVC_WhitePt;
-    XcmsColor *pColors_in_out;
-    unsigned int nColors;
+XcmsCIEuvYToTekHVC(
+    XcmsCCC ccc,
+    XcmsColor *pHVC_WhitePt,
+    XcmsColor *pColors_in_out,
+    unsigned int nColors)
 /*
  *	DESCRIPTION
  *		Transforms an array of CIECIEuvY.color specifications, given
